#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_EQ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_EQ_HPP_INCLUDED

#include <boost/simd/operator/include/functions/eq.hpp>

#endif
